clear
set more off
set mem 100000
set matsize 700
#delimit ; 
use "TIP.dta";
log using "TIP.log", replace;


/* TABLE 1: SUMMARY STATISTICS */

sum;

tab sex;

tab sex, missing;

table sex, c(mean tip mean tipper);

tab dress;

tab dress, missing;

table dress, c(mean tip mean tipper);

tab respcall;

tab respcall, missing;

table respcall, c(mean tip mean tipper);

tab luggage;

tab luggage, missing;

table luggage, c(mean tip mean tipper);

tab regular;

tab regular, m;

table regular, c(mean tip mean tipper);

tab acquaint;

tab acquaint, m;

table acquaint, c(mean tip mean tipper);

tab convers;

tab convers, m;

table convers, c(mean tip mean tipper);

tab slush;

tab slush, m;

table slush, c(mean tip mean tipper);


tab cash1 if mcash~=1;

table cash1 if mcash~=1, c(mean tip mean tipper);

/* Page 1626 & FOOTNOTE 44: NUMBERS OF DRIVER-RACE OBSERVATIONS */

tab d_race; 

/* TABLE 2: AVERAGE TIPS AND TIPPING PERCENTAGE BY DRIVER RACE */

table d_race, c(mean tip mean tipper);

/* TABLE 3: STIFFING RATE BY DRIVER RACE */

table d_race, c(mean stiff);

/* TABLE 4: AVERAGE TIPS AND TIPPING PERCENT BY PASSENGER RACE */

table race, c(mean tip mean tipper);

/* TABLE 5: STIFFING RATE BY PASSENGER RACE */

table race, c(mean stiff);

/* TABLE 6: AVERAGE TIPPING PERCENT BY PASSENGER AND DRIVER RACE */

table race d_race, c(mean tipper n tipper);

/* TABLE 7: STIFFING RATE BY PASSENGER AND DRIVER RACE */

table race d_race, c(mean stiff n stiff);

/* TABLE 10: DRIVER AND PASSENGER RACE FREQUENCY */

table d_race race, row col;

    /* Page 1647 */

tab d_race race, chi2;

    /* FOOTNOTE 93 */
tab race;


/* TABLE 11: MEAN STIFFING BY PASSENGER RACE AND FARE TYPE */

table race if fraction==0, c(mean stiff);

table race if frac25==1, c(mean stiff);

table race if frac50==1, c(mean stiff);

table race if frac75==1, c(mean stiff);


/* TABLE 13: REGRESSIONS WITH TIPPING PERCENTAGE AS DEPENDENT VARIABLE */

/* Regression 1 */
regress tipper pasian pblack phisp pother dother dblack mprace ;

outreg dblack dother pblack phisp pasian pother using TABLE13.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

     /*Page 1645 & FOOTNOTE 87*/
regress tipper pasian pblack phisp pother dother dblack mprace , cluster(cabbie);



/* Regression 2 */
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp
slush lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1, i(cabbie) re;
xttest0;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg using TABLE13.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* Regression 3 */
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp 
slush lugg cash1 pnice pnot dnice dnot mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1
/*mpuloc1 mdoloc1*/  mpuloc2 mdoloc2, i(cabbie) re;
xttest0;


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot using TABLE13.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/* Regression 4 */
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain, i(cabbie) re;
xttest0;


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using TABLE13.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

predict ptipper;
sum ptipper;
table race, c(mean ptipper);
table d_race, c(mean ptipper);




/* FOOTNOTES 151, 152 */
/*How much is driver income effected?*/

/* Regression 4 */
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain, i(cabbie) re;

adjust pasian pblack phisp pother pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain dother=0, by(dblack) se ci center;

/* Regression 4*/

xtreg amtpaid pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain, i(cabbie) re;

adjust pasian pblack phisp pother pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain dother=0, by(dblack) se ci center;

/* Regression 4*/
xtreg tip pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain, i(cabbie) re;


adjust pasian pblack phisp pother pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain dother=0, by(dblack) se ci center;

/* FOOTNOTE 43: TABLE 13 REGRESSIONS WITHOUT NEGATIVE TIPS */

/* Regression 1 */
regress tipper pasian pblack phisp pother dother dblack mprace if tip>=0;

outreg dblack dother pblack phisp pasian pother using NONNEGATIVE.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

regress tipper pasian pblack phisp pother dother dblack mprace if tip>=0, cluster(cabbie);



/* Regression 2*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp
slush lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 if tip>=0, i(cabbie) re;
xttest0;
/*xthaus;*/

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg using NONNEGATIVE.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* Regression 3 */
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp 
slush lugg cash1 pnice pnot dnice dnot mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1
/*mpuloc1 mdoloc1*/  mpuloc2 mdoloc2 if tip>=0, i(cabbie) re;
xttest0;
/*xthaus;*/


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot using NONNEGATIVE.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/* Regression 4*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if tip>=0, i(cabbie) re;
xttest0;
/*xthaus;*/

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using NONNEGATIVE.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);



/* TABLE 13 REGRESSIONS WITH DISPATCHED FARES ALONE - Page 1646 */

/* Regression 1 */
regress tipper pasian pblack phisp pother dother dblack mprace if call==1;

outreg dblack dother pblack phisp pasian pother using DISPATCHED.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

regress tipper pasian pblack phisp pother dother dblack mprace , cluster(cabbie);



/* Regression 2*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp
slush lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 if call==1, i(cabbie) re;
xttest0;
/*xthaus;*/

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg using DISPATCHED.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* Regression 3 */
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp 
slush lugg cash1 pnice pnot dnice dnot mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1
/*mpuloc1 mdoloc1*/  mpuloc2 mdoloc2 if call==1, i(cabbie) re;
xttest0;
/*xthaus;*/


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot using DISPATCHED.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/* Regression 4*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if call==1, i(cabbie) re;
xttest0;
/*xthaus;*/

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using DISPATCHED.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);



/* TABLE 13 REGRESSIONS WITH NON-DISPATCHED FARES ALONE - Page 1646 */

/* Regression 1 */
regress tipper pasian pblack phisp pother dother dblack mprace if call==0;

outreg dblack dother pblack phisp pasian pother using NONDISPATCHED.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

regress tipper pasian pblack phisp pother dother dblack mprace , cluster(cabbie);



/* Regression 2*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp
slush lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 if call==0, i(cabbie) re;
xttest0;
/*xthaus;*/

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg using NONDISPATCHED.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* Regression 3 */
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp 
slush lugg cash1 pnice pnot dnice dnot mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1
/*mpuloc1 mdoloc1*/  mpuloc2 mdoloc2 if call==0, i(cabbie) re;
xttest0;
/*xthaus;*/


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot using NONDISPATCHED.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/* Regression 4*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas /*call*/ amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if call==0, i(cabbie) re;
xttest0;
/*xthaus;*/

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using NONDISPATCHED.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* TABLE13 REGRESSIONS ON TRAIN PICK-UPS - Page 1648 & Footnote 94 */

table race if ptrain==1, c(mean tip mean tipper);
table d_race if ptrain==1, c(mean tip mean tipper);
table race d_race if ptrain==1, c(mean tip mean tipper);
tab race d_race if ptrain==1, chi2;

/* Regression 1 */
regress tipper pasian pblack phisp pother dother dblack mprace if ptrain==1;

outreg dblack dother pblack phisp pasian pother using TRAIN.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

regress tipper pasian pblack phisp pother dother dblack mprace if ptrain==1, cluster(cabbie);



/* Regression 2*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp
slush lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 if ptrain==1, i(cabbie) re;
xttest0;
/*xthaus;*/

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg using TRAIN.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* Regression 3 */
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp 
slush lugg cash1 /*pnice pnot*/ dnice dnot mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1
/*mpuloc1 mdoloc1*/  /*mpuloc2*/ mdoloc2 if ptrain==1, i(cabbie) re;
xttest0;
/*xthaus;*/


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg /*pnice pnot*/ dnice dnot using TRAIN.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/* Regression 4*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 /*pnice pnot*/ dnice dnot 
/*ptrain*/ dtrain /*puone2-puone4 puone7-puone8*/ doone2-doone3 doone5-doone7 doone9-doone10 /*putwo2-putwo9 putwo11-putwo17*/ dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ /*mpuloc2*/ mdoloc2 /*mptrain*/ mdtrain if ptrain==1, i(cabbie) re;
xttest0;
/*xthaus;*/

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg /*pnice pnot*/ dnice dnot /*ptrain*/ dtrain using TRAIN.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);



/* FOOTNOTE 147: TABLE 13 REGRESSIONS WITH TOBIT*/

/* Regression 1 */
tobit tipper pasian pblack phisp pother dother dblack mprace, ll(0);

outreg dblack dother pblack phisp pasian pother using TOBIT.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* Regression 2*/
xttobit tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp
slush lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1, i(cabbie) ll(0) re;


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg using TOBIT.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* Regression 3 */
xttobit tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp 
slush lugg cash1 pnice pnot dnice dnot mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1
/*mpuloc1 mdoloc1*/  mpuloc2 mdoloc2, i(cabbie) ll(0) re;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot using TOBIT.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/* Regression 4*/
xttobit tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain, i(cabbie) ll(0) re;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using TOBIT.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* FOOTNOTE 147: IMPOSING FILTERS */

table d_race if tipper<=2, c(mean tipper);
table d_race if tipper<=1.5, c(mean tipper);
table d_race if tipper<=1, c(mean tipper);
table d_race if tipper<=.5, c(mean tipper);
table d_race if tipper<=.25, c(mean tipper);
table d_race if (tipper>=0 & tipper<.4), c(mean tipper);

table race if tipper<=2, c(mean tipper);
table race if tipper<=1.5, c(mean tipper);
table race if tipper<=1, c(mean tipper);
table race if tipper<=.5, c(mean tipper);
table race if (tipper>=0 & tipper<.4), c(mean tipper);

/* Regression 4*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if tipper<=2, i(cabbie) re;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using FILTERS.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if tipper<=1.5, i(cabbie) re;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using FILTERS.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if tipper<=1, i(cabbie) re;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using FILTERS.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if tipper<=.5, i(cabbie) re;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using FILTERS.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if tipper<=.25, i(cabbie) re;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using FILTERS.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain if (tipper>=0 & tipper<.4), i(cabbie) re;

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using FILTERS.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);



/* TABLE 14: TESTS OF CONSUMER/PASSENGER DISCRIMINATION AGAINST DIFFERENT DRIVER RACE, BY PASSENGER RACE - post-regression
tests used to compute significance of effects as reported in table */
/* Regression 1*: Interacted Race Variables */
regress tipper dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi
 dwh_pot dbmprace dwmprace domprace;

outreg dbl_pwh dot_pwh dbl_pbl dwh_pbl dot_pbl dbl_phi dwh_phi dot_phi dbl_pas dwh_pas dot_pas dbl_pot dwh_pot dot_pot using TABLE14.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/*comparing how asians tip black drivers with how they tip others and whites*/
test dot_pas = dbl_pas;
test dwh_pas = dbl_pas;
test dot_pas = dwh_pas;
/*comparing how blacks tip black drivers with how they tip others and whites*/
test dot_pbl = dbl_pbl;
test dwh_pbl = dbl_pbl;
test dot_pbl = dwh_pbl;
/*comparing how hispanics tip black drivers with how they tip others and whites*/
test dot_phi = dbl_phi;
test dwh_phi = dbl_phi;
test dot_phi = dwh_phi;
/*comparing how others tip black drivers with how they tip others and whites*/
test dot_pot = dbl_pot;
test dwh_pot = dbl_pot;
test dot_pot = dwh_pot;
/*comparing how whites tip black drivers with how they tip others and whites*/
test dot_pwh = dbl_pwh;
/*test dwh_pwh = dbl_pwh; - implicit in significance of dbl_pwh*/

/*testing constraints on driver variables*/
testparm dot_*, equal;
testparm dbl_*, equal;
testparm dwh_*, equal;
test dwh_pas = _b[_cons], accum;
testparm dot_pas dbl_pas dwh_pas, equal;
testparm dot_pbl dbl_pbl dwh_pbl, equal;
testparm dot_phi dbl_phi dwh_phi, equal;
testparm dot_pot dbl_pot dwh_pot, equal;
testparm dot_pwh dbl_pwh, equal;
test dot_pwh = _b[_cons], accum;

regress tipper dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot dbmprace dwmprace domprace, cluster(cabbie);
/*comparing how asians tip black drivers with how they tip others and whites*/
test dot_pas = dbl_pas;
test dwh_pas = dbl_pas;
test dot_pas = dwh_pas;
/*comparing how blacks tip black drivers with how they tip others and whites*/
test dot_pbl = dbl_pbl;
test dwh_pbl = dbl_pbl;
test dot_pbl = dwh_pbl;
/*comparing how hispanics tip black drivers with how they tip others and whites*/
test dot_phi = dbl_phi;
test dwh_phi = dbl_phi;
test dot_phi = dwh_phi;
/*comparing how others tip black drivers with how they tip others and whites*/
test dot_pot = dbl_pot;
test dwh_pot = dbl_pot;
test dot_pot = dwh_pot;
/*comparing how whites tip black drivers with how they tip others and whites*/
test dot_pwh = dbl_pwh;
/*test dwh_pwh = dbl_pwh; - implicit in significance of dbl_pwh*/

/*testing constraints on driver variables*/
testparm dot_*, equal;
testparm dbl_*, equal;
testparm dwh_*, equal;
test dwh_pas = _b[_cons], accum;
testparm dot_pas dbl_pas dwh_pas, equal;
testparm dot_pbl dbl_pbl dwh_pbl, equal;
testparm dot_phi dbl_phi dwh_phi, equal;
testparm dot_pot dbl_pot dwh_pot, equal;
testparm dot_pwh dbl_pwh, equal;
test dot_pwh = _b[_cons], accum;

/* Regression 2*: Random Effects Version of Interacted Race Variables, Other Variables*/
xtreg tipper dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age ageint talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 
trnsmin trnsmile speed night late temp slush lugg cash1 dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime 
mslush mlugg mcash1, i(cabbie) re;
xttest0;
/*xthaus;*/


outreg dbl_pwh dot_pwh dbl_pbl dwh_pbl dot_pbl dbl_phi dwh_phi dot_phi dbl_pas dwh_pas dot_pas dbl_pot dwh_pot dot_pot using TABLE14.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/*comparing how asians tip black drivers with how they tip others and whites*/
test dot_pas = dbl_pas;
test dwh_pas = dbl_pas;
test dot_pas = dwh_pas;
/*comparing how blacks tip black drivers with how they tip others and whites*/
test dot_pbl = dbl_pbl;
test dwh_pbl = dbl_pbl;
test dot_pbl = dwh_pbl;
/*comparing how hispanics tip black drivers with how they tip others and whites*/
test dot_phi = dbl_phi;
test dwh_phi = dbl_phi;
test dot_phi = dwh_phi;
/*comparing how others tip black drivers with how they tip others and whites*/
test dot_pot = dbl_pot;
test dwh_pot = dbl_pot;
test dot_pot = dwh_pot;
/*comparing how whites tip black drivers with how they tip others and whites*/
test dot_pwh = dbl_pwh;
/*test dwh_pwh = dbl_pwh; - implicit in significance of dbl_pwh*/

/*testing constraints on driver variables*/
testparm dot_*, equal;
testparm dbl_*, equal;
testparm dwh_*, equal;
test dwh_pas = _b[_cons], accum;
testparm dot_pas dbl_pas dwh_pas, equal;
testparm dot_pbl dbl_pbl dwh_pbl, equal;
testparm dot_phi dbl_phi dwh_phi, equal;
testparm dot_pot dbl_pot dwh_pot, equal;
testparm dot_pwh dbl_pwh, equal;
test dot_pwh = _b[_cons], accum;

/* Regression 3*:  Random Effects Version of Interacted Race Variables, Other Variables, Continuous Location Variables, 3 Categorical Location Variables */
xtreg tipper dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age ageint  talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75
 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot  dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow 
m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */  mpuloc2 mdoloc2, i(cabbie) re;
xttest0;
/*xthaus;*/


outreg dbl_pwh dot_pwh dbl_pbl dwh_pbl dot_pbl dbl_phi dwh_phi dot_phi dbl_pas dwh_pas dot_pas dbl_pot dwh_pot dot_pot using TABLE14.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/*comparing how asians tip black drivers with how they tip others and whites*/
test dot_pas = dbl_pas;
test dwh_pas = dbl_pas;
test dot_pas = dwh_pas;
/*comparing how blacks tip black drivers with how they tip others and whites*/
test dot_pbl = dbl_pbl;
test dwh_pbl = dbl_pbl;
test dot_pbl = dwh_pbl;
/*comparing how hispanics tip black drivers with how they tip others and whites*/
test dot_phi = dbl_phi;
test dwh_phi = dbl_phi;
test dot_phi = dwh_phi;
/*comparing how others tip black drivers with how they tip others and whites*/
test dot_pot = dbl_pot;
test dwh_pot = dbl_pot;
test dot_pot = dwh_pot;
/*comparing how whites tip black drivers with how they tip others and whites*/
test dot_pwh = dbl_pwh;
/*test dwh_pwh = dbl_pwh; - implicit in significance of dbl_pwh*/

/*testing constraints on driver variables*/
testparm dot_*, equal;
testparm dbl_*, equal;
testparm dwh_*, equal;
test dwh_pas = _b[_cons], accum;
testparm dot_pas dbl_pas dwh_pas, equal;
testparm dot_pbl dbl_pbl dwh_pbl, equal;
testparm dot_phi dbl_phi dwh_phi, equal;
testparm dot_pot dbl_pot dwh_pot, equal;
testparm dot_pwh dbl_pwh, equal;
test dot_pwh = _b[_cons], accum;

/* Regression 4*:  Random Effects Version of Interacted Race Variables, Other Variables, Continuous Location Variables, 3 Categorical Location Variables, Neighborhood Variables */
xtreg tipper dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot
pfem age beldress abodress exp survexp d_age ageint talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain, i(cabbie) re;
xttest0;
/*xthaus;*/


outreg dbl_pwh dot_pwh dbl_pbl dwh_pbl dot_pbl dbl_phi dwh_phi dot_phi dbl_pas dwh_pas dot_pas dbl_pot dwh_pot dot_pot using TABLE14.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/*comparing how asians tip black drivers with how they tip others and whites*/
test dot_pas = dbl_pas;
test dwh_pas = dbl_pas;
test dot_pas = dwh_pas;
/*comparing how blacks tip black drivers with how they tip others and whites*/
test dot_pbl = dbl_pbl;
test dwh_pbl = dbl_pbl;
test dot_pbl = dwh_pbl;
/*comparing how hispanics tip black drivers with how they tip others and whites*/
test dot_phi = dbl_phi;
test dwh_phi = dbl_phi;
test dot_phi = dwh_phi;
/*comparing how others tip black drivers with how they tip others and whites*/
test dot_pot = dbl_pot;
test dwh_pot = dbl_pot;
test dot_pot = dwh_pot;
/*comparing how whites tip black drivers with how they tip others and whites*/
test dot_pwh = dbl_pwh;
/*test dwh_pwh = dbl_pwh; - implicit in significance of dbl_pwh*/

/*testing constraints on driver variables*/
testparm dot_*, equal;
testparm dbl_*, equal;
testparm dwh_*, equal;
test dwh_pas = _b[_cons], accum;
testparm dot_pas dbl_pas dwh_pas, equal;
testparm dot_pbl dbl_pbl dwh_pbl, equal;
testparm dot_phi dbl_phi dwh_phi, equal;
testparm dot_pot dbl_pot dwh_pot, equal;
testparm dot_pwh dbl_pwh, equal;
test dot_pwh = _b[_cons], accum;

/* TABLE 15: REGRESSIONS WITH STIFFING AS DEPENDENT VARIABLE */
/* Regression 1 */
dprobit stiff pasian pblack phisp pother dother dblack mprace ;

outreg dblack dother pblack phisp pasian pother using TABLE15.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);
    
    /*Page 1645 & FOOTNOTE 86*/
dprobit stiff pasian pblack phisp pother dother dblack mprace , cluster(cabbie);



/* Regression 2*/
dprobit stiff pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp 
slush lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1,  cluster(cabbie);

outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg using TABLE15.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);


/* Regression 3 */
dprobit stiff pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas
 call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2,  cluster(cabbie);


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot using TABLE15.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/* Regression 4*/
dprobit stiff pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain,  cluster(cabbie);


outreg dblack dother pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using TABLE15.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

/* TABLE 8: IRRATIONAL STATISTICAL DISCRIMINATOR REGRESSIONS - FARE AND TIP */

regress amtdue pasian pblack phisp pother  mprace /*dother dblack*/;
 
regress tip pasian pblack phisp pother  mprace /*dother dblack*/;

adjust mprace pasian=0 phisp=0 pother=0, by(pblack) se ci center;
adjust mprace pblack=0 phisp=0 pother=0, by(pasian) se ci center;
adjust mprace pasian=0 pblack=0 pother=0, by(phisp) se ci center;
adjust mprace pasian=0 phisp=0 pblack=0, by(pother) se ci center;

regress tipper pasian pblack phisp pother  mprace /*dother dblack*/;

adjust mprace pasian=0 phisp=0 pother=0, by(pblack) se ci center;
adjust mprace pblack=0 phisp=0 pother=0, by(pasian) se ci center;
adjust mprace pasian=0 pblack=0 pother=0, by(phisp) se ci center;
adjust mprace pasian=0 phisp=0 pblack=0, by(pother) se ci center;

regress amtpaid pasian pblack phisp pother  mprace /*dother dblack*/;

adjust mprace pasian=0 phisp=0 pother=0, by(pblack) se ci center;
adjust mprace pblack=0 phisp=0 pother=0, by(pasian) se ci center;
adjust mprace pasian=0 pblack=0 pother=0, by(phisp) se ci center;
adjust mprace pasian=0 phisp=0 pblack=0, by(pother) se ci center;

regress amtdue pasian pblack phisp pother  mprace /*dother dblack*/, cluster(cabbie);
regress tip pasian pblack phisp pother  mprace /*dother dblack*/, cluster(cabbie);

/* TABLE 8: RATIONAL STATISTICAL DISCRIMINATOR REGRESSIONS - FARE AND TIP */

xtreg amtdue pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain, i(cabbie) re;

/* TABLE 9: TIPPING SHORTFALL ESTIMATED BY "RATIONAL DISCRIMINATORS" */

xtreg tip pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain, i(cabbie) re;

/* TABLE 9: PREDICTED WHITE-PASSENGER TIP EVALUATED AT THE MEANS OF THE NON-PASSENGER-RACE VARIABLES */ 

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 phisp=0 pother=0, by(pblack) se ci center;

/* TABLE 9: PREDICTED WHITE-PASSENGER TIP EVALUATED AT THE MEANS OF THE NON-PASSENGER-RACE VARIABLES */  

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pblack=0 phisp=0 pother=0, by(pasian) se ci center;

/* TABLE 9: PREDICTED WHITE-PASSENGER TIP EVALUATED AT THE MEANS OF THE NON-PASSENGER-RACE VARIABLES */ 

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 pblack=0 pother=0, by(phisp) se ci center;

/* TABLE 9: PREDICTED WHITE-PASSENGER TIP EVALUATED AT THE MEANS OF THE NON-PASSENGER-RACE VARIABLES */  

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 phisp=0 pblack=0, by(pother) se ci center;

xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain, i(cabbie) re;


adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 phisp=0 pother=0, by(pblack) se ci center;

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pblack=0 phisp=0 pother=0, by(pasian) se ci center;

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 pblack=0 pother=0, by(phisp) se ci center;

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 phisp=0 pblack=0, by(pother) se ci center;

xtreg amtpaid pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain, i(cabbie) re;


adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 phisp=0 pother=0, by(pblack) se ci center;

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pblack=0 phisp=0 pother=0, by(pasian) se ci center;

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 pblack=0 pother=0, by(phisp) se ci center;

adjust pfem age beldress abodress exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2 mptrain pasian=0 phisp=0 pblack=0, by(pother) se ci center;


/* NATIVE V. NON-NATIVE ANALYSIS: TABLE 13 REGRESSIONS WITH NATIVE DATA - Page 1645 & Footnote 87 */

generate native=1 if cabbie==1 | cabbie==2 | cabbie==5 | cabbie==6|  cabbie==8 | cabbie==10;
replace native=0 if cabbie==4 | cabbie==9 | cabbie==11 | cabbie==12;
gen mnative=1 if native==.;
replace mnative=0 if native~=.;

gen foreign=1-native;
replace foreign=0 if mnative==1;

tab native, m;
tab mnative, m;
tab foreign, m;

generate dbalien=dblack*foreign;
generate dbmiss=dblack*mnative;

tab dbalien, m;
tab dbmiss, m;


regress tipper pasian pblack phisp pother dother dblack dbalien dbmiss mprace ;

outreg dblack dother dbalien pblack phisp pasian pother using NATIVE.xls, replace noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

test dblack=dbalien;
test dblack dbalien;
test dblack + dbalien=0;



/* Regression 4*/
xtreg tipper pasian pblack phisp pother pfem age beldress abodress dother dblack dbalien dbmiss exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1 */ mpuloc2 mdoloc2 mptrain mdtrain, i(cabbie) re;
xttest0;


outreg dblack dother dbalien pblack phisp pasian pother pfem age beldress abodress exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 cash1 trnsmin trnsmile speed night late temp
slush lugg pnice pnot dnice dnot ptrain dtrain using NATIVE.xls, append noparen nolabel coefastr pvalue 3aster nonotes bdec(8);

test dblack=dbalien;
test dblack dbalien;
test dblack + dbalien=0;



/*ROUNDING 1654-1655*/

replace d_race="Other" if d_race=="Arabic" | d_race=="Asian";

gen str9 temp2=string(amtpaid) if amtpaid~=.;
gen nround=index(temp2, ".");
tab nround;
gen round=(nround==0) if amtpaid~=.;
replace round=0 if stiff==1;

/* TABLE 12: TOTAL NOT ROUNDED */

tab round;

/* TABLE 12: TOTAL ROUNDED */

table round stiff;


table race, c(mean tipper);
gen exppay=amtdue + .1619226*amtdue if race=="Asian";
replace exppay=amtdue + .0919185*amtdue if race=="Black";
replace exppay=amtdue + .1197305*amtdue if race=="Hispanic";
replace exppay=amtdue + .1065801*amtdue if race=="Other";
replace exppay=amtdue + .2164162*amtdue if race=="White";
sum exppay;
gen rup=(round==1 & amtpaid>exppay);
tab rup stiff;
gen rdown=(round==1 & amtpaid<exppay);
tab rdown stiff;

gen round1=(round==1 & amtpaid>exppay-1 & amtpaid<exppay+1);
tab round1, m;
table round1 stiff;

gen dist1=.5 if round==0 & amtpaid>=exppay & amtpaid<exppay+1;
replace dist1=-.5 if round==0 & amtpaid>exppay-1 & amtpaid<=exppay;
replace dist1=1 if round==1 & amtpaid>exppay & amtpaid<exppay+1;
replace dist1=-1 if round==1 & amtpaid>exppay-1 & amtpaid<=exppay;
replace dist1=1.5 if round==0 & (amtpaid<exppay+2 & amtpaid>=exppay+1);
replace dist1=-1.5 if round==0 & (amtpaid>exppay-2 & amtpaid<=exppay-1);
replace dist1=2 if round==1 & (amtpaid<exppay+2 & amtpaid>=exppay+1);
replace dist1=-2 if round==1 & (amtpaid>exppay-2 & amtpaid<=exppay-1);
replace dist1=2.5 if round==0 & (amtpaid<exppay+3 & amtpaid>=exppay+2);
replace dist1=-2.5 if round==0 & (amtpaid>exppay-3 & amtpaid<=exppay-2);
replace dist1=3 if round==1 & (amtpaid<exppay+3 & amtpaid>=exppay+2);
replace dist1=-3 if round==1 & (amtpaid>exppay-3 & amtpaid<=exppay-2);
replace dist1=3.5 if round==0 & (amtpaid<exppay+4 & amtpaid>=exppay+3);
replace dist1=-3.5 if round==0 & (amtpaid>exppay-4 & amtpaid<=exppay-3);
replace dist1=4 if round==1 & (amtpaid<exppay+4 & amtpaid>=exppay+3);
replace dist1=-4 if round==1 & (amtpaid>exppay-4 & amtpaid<=exppay-3);
replace dist1=4.5 if round==0 & (amtpaid<exppay+5 & amtpaid>=exppay+4);
replace dist1=-4.5 if round==0 & (amtpaid>exppay-5 & amtpaid<=exppay-4);
replace dist1=5 if round==1 & (amtpaid<exppay+5 & amtpaid>=exppay+4);
replace dist1=-5 if round==1 & (amtpaid>exppay-5 & amtpaid<=exppay-4);
replace dist1=5.5 if round==0 & (amtpaid<exppay+6 & amtpaid>=exppay+5);
replace dist1=-5.5 if round==0 & (amtpaid>exppay-6 & amtpaid<=exppay-5);
replace dist1=6 if round==1 & (amtpaid<exppay+6 & amtpaid>=exppay+5);
replace dist1=-6 if round==1 & (amtpaid>exppay-6 & amtpaid<=exppay-5);
replace dist1=6.5 if round==0 & (amtpaid<exppay+7 & amtpaid>=exppay+6);
replace dist1=-6.5 if round==0 & (amtpaid>exppay-7 & amtpaid<=exppay-6);
replace dist1=7 if round==1 & (amtpaid<exppay+7 & amtpaid>=exppay+6);
replace dist1=-7 if round==1 & (amtpaid>exppay-7 & amtpaid<=exppay-6);
replace dist1=7.5 if round==0 & (amtpaid<exppay+8 & amtpaid>=exppay+7);
replace dist1=-7.5 if round==0 & (amtpaid>exppay-8 & amtpaid<=exppay-7);
replace dist1=8 if round==1 & (amtpaid<exppay+8 & amtpaid>=exppay+7);
replace dist1=-8 if round==1 & (amtpaid>exppay-8 & amtpaid<=exppay-7);
replace dist1=8.5 if round==0 & (amtpaid<exppay+9 & amtpaid>=exppay+8);
replace dist1=-8.5 if round==0 & (amtpaid>exppay-9 & amtpaid<=exppay-8);
replace dist1=9 if round==1 & (amtpaid<exppay+9 & amtpaid>=exppay+8);
replace dist1=-9 if round==1 & (amtpaid>exppay-9 & amtpaid<=exppay-8);
replace dist1=9.5 if round==0 & (amtpaid<exppay+10 & amtpaid>=exppay+9);
replace dist1=-9.5 if round==0 & (amtpaid>exppay-10 & amtpaid<=exppay-9);
replace dist1=10 if round==1 & (amtpaid<exppay+10 & amtpaid>=exppay+9);
replace dist1=-10 if round==1 & (amtpaid>exppay-10 & amtpaid<=exppay-9);
replace dist1=99.5 if round==0 & (amtpaid>=exppay+10);
replace dist1=-99.5 if round==0 & (amtpaid<=exppay-10);
replace dist1=100 if round==1 & (amtpaid>=exppay+10);
replace dist1=-100 if round==1 & (amtpaid<=exppay-10);

/* TABLE 12: ROUNDED UP & ROUNDED DOWN TO THE NEAREST INTEGER */

tab dist1 if (dist1==1 | dist1==-1);
tab round1;

sum round1;
table race, c(mean round1);
table d_race, c(mean round1);


/* ROUND-UP AVERAGES (FROM WHICH ROUNDING UP V. DOWN DISCREPANCIES ARE CALCULATED) */

gen rup1=(round==1 & amtpaid>exppay & amtpaid<exppay+1);

table race if round1==1, c(mean rup1);
table d_race if round1==1, c(mean rup1);
table race d_race if round1==1, c(mean rup1 n rup1) row col;

/* ROUNDING1 PERCENTAGES BY PASSENGER & DRIVER RACE (FOR ROUNDING DISCREPANCY) */

      /*proportion rounded to within 1*/
table race, c(mean round1 n round1) row col;
table race d_race, c(mean round1 n round1) row col;
table race d_race if (d_race=="White" | d_race=="Black"), c(mean round1 n round1) row col;

/* PROPORTION STIFFED (OF NON-ROUNDED FARES) BY PASSENGER & DRIVER RACE (FOR STIFFING DISCREPANCY) */
     /*proportion stiffed if NOT rounded within 1*/
table race if round1==0, c(mean stiff n stiff) row col;
table race d_race if round1==0, c(mean stiff n stiff) row col;
table race d_race if round1==0 & (d_race=="White" | d_race=="Black"), c(mean stiff n stiff) row col;


/* ROUNDED1 TIPPING % AVERAGES (FOR ROUNDING AND STIFFING DISCREPANCY) */
table race d_race if stiff==0 & round1==1, c(mean tipper n tipper) row col;
table race d_race if stiff==0 & round1==1 & (d_race=="White" | d_race=="Black"), c(mean tipper n tipper) row col;




/* Page 1618 & FOOTNOTE 6 */
table race, c(mean rup1 n rup1);
table d_race, c(mean rup1 n rup1);
table race d_race, c(mean rup1 n rup1) row col;


table race d_race if (d_race=="White" | d_race=="Black"), c(mean round1 n round1) row col;
table race d_race if round1==1 & (d_race=="White" | d_race=="Black"), c(mean tipper n tipper) row col;
table race d_race if (d_race=="White" | d_race=="Black"), c(mean stiff n stiff) row col;
table race d_race if stiff==0  & (d_race=="White" | d_race=="Black"), c(mean tipper n tipper) row col;
table race d_race if (d_race=="White" | d_race=="Black"), c(mean tipper n tipper) row col;


/* CORE REGRESSIONS WITH rup1 AS RHS VARIABLE - denominator all fares*/
/* Regression 1 */
dprobit rup1 pasian pblack phisp pother dother dblack mprace ;
dprobit rup1 pasian pblack phisp pother dother dblack mprace , cluster(cabbie);


/* Regression 2*/
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush
 lugg cash1  mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1;
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush
 lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1,  cluster(cabbie);



/* Regression 3 */
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call 
amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2;
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas 
call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2,  cluster(cabbie);


/* Regression 4*/
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call 
amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain;
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain,  cluster(cabbie);


/*CORE REGRESSIONS WITH rup1 AS RHS VARIABLE - denominator all fares: Passenger Discrimination Regressions*/
/* Regression 1* */
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot dbmprace dwmprace domprace;
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot dbmprace dwmprace domprace, cluster(cabbie);

/* Regression 2* */
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile
 speed night late temp slush lugg cash1 dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1;
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin 
trnsmile speed night late temp slush lugg cash1 dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1, cluster(cabbie);

/* Regression 3* */
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin
 trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1
 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2;
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin
 trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall
 mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2, cluster(cabbie);

/* Regression 4* */
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75
 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain;
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain, cluster(cabbie);



/* CORE REGRESSIONS WITH rup1 AS RHS VARIABLE - denominator rounded1fares*/
/* Regression 1 */
dprobit rup1 pasian pblack phisp pother dother dblack mprace  if round1==1;
dprobit rup1 pasian pblack phisp pother dother dblack mprace  if round1==1, cluster(cabbie);


/* Regression 2*/
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush 
lugg cash1  mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 if round1==1;
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp 
survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush
 lugg cash1 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 if round1==1,  cluster(cabbie);


/* Regression 3 */
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas 
call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 if round1==1;
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas 
call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 if round1==1,  cluster(cabbie);


/* Regression 4*/
dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain if round1==1;

dprobit rup1 pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
 mprace  mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain if round1==1,  cluster(cabbie);

/*CORE REGRESSIONS WITH rup1 AS RHS VARIABLE - denominator rounded1 fares: Passenger Discrimination Regressions*/
/* Regression 1* */
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot dbmprace dwmprace domprace if round1==1;
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot dbmprace dwmprace domprace if round1==1, cluster(cabbie);

/* Regression 2* */
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin 
trnsmile speed night late temp slush lugg cash1  dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 if round1==1;
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 
 dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 if round1==1, cluster(cabbie);

/* Regression 3* */
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin
 trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot 
 dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 if round1==1;
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot 
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin 
trnsmile speed night late temp slush lugg cash1 pnice pnot dnice
 dnot  dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 if round1==1, cluster(cabbie);


/*Regression 4* */
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
  dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain if round1==1;
dprobit rup1 dot_pas dot_pbl dot_phi dot_pot dot_pwh dbl_pas dbl_pbl dbl_phi dbl_pot dbl_pwh dwh_pas dwh_pbl dwh_phi dwh_pot
pfem age beldress abodress exp survexp d_age talk repeat know multpas call amtdue amtdue2 frac25 frac50 frac75 trnsmin trnsmile speed night late temp slush lugg cash1 pnice pnot dnice dnot
ptrain dtrain puone2-puone4 puone7-puone8 doone2-doone3 doone5-doone7 doone9-doone10 putwo2-putwo9 putwo11-putwo17 dotwo2-dotwo3 dotwo5-dotwo15 dotwo17-dotwo22
  dbmprace dwmprace domprace mpfem mdress mtalk mrepeat mknow m_mtpas mcall mfrac mtime mslush mlugg mcash1 /*mpuloc1 mdoloc1*/ mpuloc2 mdoloc2 mptrain mdtrain if round1==1, cluster(cabbie);



/*Suburbs*/

tab pnearsub;
tab dnearsub;

/*FAR SUBURBS*/

tab pfarsub;
tab dfarsub;


table race, c(mean dfarsub count dfarsub) row col;
table race, c(mean dnearsub count dnearsub) row col;


table dfarsub race, row col;
table dnearsub race, row col;

/* Table 8: IRRATIONAL STATISTICAL DISCRIMINATOR REGRESSIONS WITH PFARSUBURB */

dprobit dfarsub pasian pblack phisp pother mprace /*dother dblack*/;
dprobit dfarsub pasian pblack phisp pother mprace /*dother dblack*/, cluster(cabbie);

/* Table 8: RATIONAL STATISTICAL DISCRIMINATOR REGRESSIONS WITH PFARSUBURB  */

dprobit dfarsub pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2  mptrain ;
dprobit dfarsub pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2  mptrain , cluster(cabbie);

dprobit dnearsub pasian pblack phisp pother mprace /*dother dblack*/;
dprobit dnearsub pasian pblack phisp pother mprace /*dother dblack*/, cluster(cabbie);
dprobit dnearsub pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2  mptrain ;
dprobit dnearsub pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2  mptrain , cluster(cabbie);


/*dispatch probabilities*/
tab pu_loc2 if call==1;


/*deadhead probabilities (or 1-deadhead probabilities)*/


table race, c(mean pdisp) row col;
table d_race, c(mean pdisp) row col;

/* FOOTNOTE 73 */

table race if call==1, c(mean pdisp) row col;
table d_race if call==1, c(mean pdisp) row col;


table pdisp race, row col;
table pdisp d_race, row col;

gen dhead=1-pdisp;


table race, c(mean dhead) row col;
table d_race, c(mean dhead) row col;

table race if call==1, c(mean dhead) row col;
table d_race if call==1, c(mean dhead) row col;

table dhead race, row col;
table dhead d_race, row col;

/*Observational Regressions with dispatch & deadhead probs*/
reg pdisp pasian pblack phisp pother mprace /*dother dblack*/;
reg pdisp pasian pblack phisp pother mprace /*dother dblack*/, cluster(cabbie);
reg pdisp pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2  mptrain , cluster(cabbie);

reg dhead pasian pblack phisp pother mprace /*dother dblack*/;
reg dhead pasian pblack phisp pother mprace  /*dother dblack*/, cluster(cabbie);
reg dhead pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot 
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2  mptrain , cluster(cabbie);


table race, c(mean call) row col;
table d_race, c(mean call) row col;

/* Table 8: IRRATIONAL STATISTICAL DISCRIMINATOR REGRESSIONS WITH STIFF */

dprobit stiff pasian pblack phisp pother mprace /*dother dblack*/;
dprobit stiff pasian pblack phisp pother mprace /*dother dblack*/, cluster(cabbie);

/* Table 8: RATIONAL STATISTICAL DISCRIMINATOR REGRESSIONS WITH STIFF  */

dprobit stiff pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2  mptrain ;
dprobit stiff pasian pblack phisp pother pfem age beldress abodress dother dblack exp survexp d_age repeat know multpas call night late temp slush lugg pnice pnot
ptrain puone2-puone4 puone7-puone8 putwo2-putwo9 putwo11-putwo17 mprace  mpfem mdress mrepeat mknow m_mtpas mcall mtime mslush mlugg
/*mpuloc1*/ mpuloc2  mptrain , cluster(cabbie);


/* CABBIE TIPPING MEANS AND NUMBERS (FOOTNOTE 83) */

table cabbie, c(mean tipper n tipper) row;
table race cabbie, c(mean tipper n tipper) row col;
table cabbie d_race;

/* NUMBER OF DRIVER-DAY OBSERVATIONS, & NUMBER WITH FEWER THAN 10 FARES - page 1643 */

sort cabbie date;
collapse (count) number=decimal, by(cabbie date);
count;
count if number<10;

log close;


